@@ -115,7 +115,7 @@ def add_format_to_calibre(item_id, filename):
     """
     print " ... importing %s as new format for item %s" % (filename, item_id)
     subprocess.check_call(
-        [config.calibredb, "add_format", item_id, rtf_name])
+        [config.calibredb, "add_format", item_id, filename])
     print " ... imported"
 
 ############################################################
