@@ -81,7 +81,7 @@ def make_rtf_for(item):
     try:
         rtf_file.close()
         doc2rtf_converter.convert(item.file, rtf_name)
-        add_format_to_calibre(item_id, rtf_name)
+        add_format_to_calibre(item.id, rtf_name)
     finally:
         os.remove(rtf_name)
 
