@@ -12,15 +12,10 @@ all to calibre, pipe output. For example:
 (but, better, review everything beforehand)
 """
 
-#import os.path
-#import subprocess
-#from lxml import objectify
-#from StringIO import StringIO
-#import sys
-
+import os.path
+import sys
 from mekk.calibre.calibre_util import find_calibre_file_names
 from mekk.calibre.disk_util import find_disk_files
-import os.path
 
 ############################################################
 # Main
